@@ -1153,7 +1153,7 @@ sub new_user_amazon {
    if ($cleanup) {
       my $fullauto_inst=get_fullauto_instance();
       my $i=$fullauto_inst->{InstanceId};
-      $t="aws ec2 terminate-instances --instance-id $i";
+      my $t="aws ec2 terminate-instances --instance-id $i";
       ($hash,$output,$error)=run_aws_cmd($t);
       Net::FullAuto::FA_Core::cleanup();
    }
